@@ -43,6 +43,7 @@
 
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
+#include <libgnome/libgnome.h>
 #include <libgnomeui/gnome-about.h>
 #include <libgnomeui/gnome-window-icon.h>
 #include <panel-applet.h>
@@ -96,6 +97,7 @@
 #define VOLUME_DEFAULT_ICON_SIZE 48
 static GtkIconSize volume_icon_size = 0;
 static gboolean icons_initialized = FALSE;
+static gboolean device_present = TRUE;
 
 #define IS_PANEL_HORIZONTAL(o) (o == PANEL_APPLET_ORIENT_UP || o == PANEL_APPLET_ORIENT_DOWN)
 
@@ -127,6 +129,7 @@ typedef struct {
 	gint		    channel;
 	int 		    mixerchannel;
 	GList		    *channels;
+	gchar		    *device;
 
 	GtkAdjustment     *adj;
 
@@ -138,6 +141,8 @@ typedef struct {
 	/* The popup window and scale. */
 	GtkWidget         *popup;
 	GtkWidget         *scale;
+	
+	GtkWidget 		*error_dialog;
 
 	GdkPixbuf	  *zero;
 	GdkPixbuf	  *min;
@@ -164,6 +169,7 @@ static gchar *run_mixer_cmd = NULL;
 
 static const gchar *access_name = N_("Volume Control");     
 static const gchar *access_name_mute = N_("Volume Control (muted)");
+static const gchar *access_name_nodevice = N_("No audio device");
 gboolean gail_loaded = FALSE;  
 
 
@@ -372,6 +378,22 @@ mixer_timeout_cb (MixerData *data)
 	gint               vol;
 	gboolean state;
 
+	if (!device_present) {
+		data->mute = TRUE;
+		mixer_update_image (data);
+
+		gtk_tooltips_set_tip (data->tooltips,
+				      data->applet,
+				      _(access_name_nodevice),
+				      NULL);
+		if (gail_loaded) {
+			add_atk_namedesc (data->applet,
+					  _(access_name_nodevice),
+					  NULL);
+		}
+		return TRUE;
+	}
+
 #ifdef SUN_API
 	state = get_mute_status ();
 
@@ -559,6 +581,36 @@ scale_key_press_event_cb (GtkWidget *widget, GdkEventKey *event, MixerData *data
 
 	return FALSE;
 }
+
+static void
+error_response (GtkDialog *dialog, gint id, MixerData *data)
+{
+	gtk_widget_destroy (data->error_dialog);
+	data->error_dialog = NULL;
+}
+
+static void
+show_error_dialog (MixerData *data)
+{	
+	if (data->error_dialog) {
+		gtk_window_present (GTK_WINDOW (data->error_dialog));
+		return;
+	}
+	data->error_dialog = gtk_message_dialog_new (NULL,
+					 GTK_DIALOG_DESTROY_WITH_PARENT,
+					 GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
+					 ("Couldn't open mixer device %s\n"),
+					 data->device, NULL);
+
+	gtk_window_set_screen (GTK_WINDOW (data->error_dialog),
+			       gtk_widget_get_screen (GTK_WIDGET (data->applet)));
+	g_signal_connect (GTK_OBJECT (data->error_dialog), 
+                             "response", 
+                             G_CALLBACK (error_response),
+                             data);
+        gtk_widget_show_all (data->error_dialog);
+}
+
 static gboolean
 scale_button_release_event_cb (GtkWidget *widget, GdkEventButton *event, MixerData *data)
 {
@@ -571,14 +623,22 @@ scale_button_release_event_cb (GtkWidget *widget, GdkEventButton *event, MixerDa
 	return FALSE;
 }
 
+static gboolean
+scale_button_event  (GtkWidget *widget, GdkEventButton *event, MixerData *data)
+{
+	return TRUE;
+}
+
 static gboolean
 applet_button_release_event_cb (GtkWidget *widget, GdkEventButton *event, MixerData *data)
 {
+
 	if (event->button == 1) {
-		if (data->popup == NULL) {
+		if (data->popup == NULL && device_present) {
 			mixer_popup_show (data);
 			return TRUE;
-		}
+		} else if (!device_present)
+			show_error_dialog (data);
 	}
 
 	return FALSE;
@@ -602,8 +662,10 @@ applet_key_press_event_cb (GtkWidget *widget, GdkEventKey *event, MixerData *dat
 		/* Apply. */
 		if (data->popup != NULL)
 			mixer_popup_hide (data, FALSE);
-		else
+		else if(device_present)
 			mixer_popup_show (data);
+		else
+			show_error_dialog (data);
 		return TRUE;
 
 	default:
@@ -649,6 +711,9 @@ mixer_popup_show (MixerData *data)
 	GtkRequisition  req;
 	GtkWidget      *frame;
 	GtkWidget      *inner_frame;
+	GtkWidget      *pluslabel, *minuslabel;
+	GtkWidget 	     *event;
+	GtkWidget 	     *box;
 	gint            x, y;
 	gint            width, height;
 	GdkGrabStatus   pointer, keyboard;
@@ -669,10 +734,18 @@ mixer_popup_show (MixerData *data)
 	gtk_frame_set_shadow_type (GTK_FRAME (inner_frame), GTK_SHADOW_NONE);
 	gtk_widget_show (inner_frame);
 	
+	event = gtk_event_box_new ();
+	/* This signal is to not let button press close the popup when the press is
+	** in the scale */
+	g_signal_connect_after (event, "button_press_event",
+				  G_CALLBACK (scale_button_event), data);
+	
 	if (IS_PANEL_HORIZONTAL (data->orientation)) {
+		box = gtk_vbox_new (FALSE, 0);
 		data->scale = gtk_vscale_new (data->adj);
 		gtk_widget_set_size_request (data->scale, -1, 100);			
 	} else {
+		box = gtk_hbox_new (FALSE, 0);
 		data->scale = gtk_hscale_new (data->adj);
 		gtk_widget_set_size_request (data->scale, 100, -1);
 		gtk_range_set_inverted (GTK_RANGE (data->scale), TRUE);
@@ -683,8 +756,8 @@ mixer_popup_show (MixerData *data)
 				_("Volume Controller"),
 				_("Use Up/Down arrow keys to change volume"));
 	}
-	g_signal_connect (data->scale,
-			  "button-release-event",
+	g_signal_connect_after (data->popup,
+			  "button-press-event",
 			  (GCallback) scale_button_release_event_cb,
 			  data);
 
@@ -702,8 +775,24 @@ mixer_popup_show (MixerData *data)
 	gtk_container_add (GTK_CONTAINER (data->popup), frame);
 	
 	gtk_container_add (GTK_CONTAINER (frame), inner_frame);
-	gtk_container_add (GTK_CONTAINER (inner_frame), data->scale);
-
+	
+	/* Translators - The + and - refer to increasing and decreasing the volume. 
+	** I don't know if there are sensible alternatives in other languages */
+	pluslabel = gtk_label_new (_("+"));	
+	minuslabel = gtk_label_new (_("-"));
+	
+	if (IS_PANEL_HORIZONTAL (data->orientation)) {
+		gtk_box_pack_start (GTK_BOX (box), pluslabel, FALSE, FALSE, 0);
+		gtk_box_pack_end (GTK_BOX (box), minuslabel, FALSE, FALSE, 0);
+	} else {
+		gtk_box_pack_start (GTK_BOX (box), minuslabel, FALSE, FALSE, 0);
+		gtk_box_pack_end (GTK_BOX (box), pluslabel, FALSE, FALSE, 0);
+	}
+	gtk_box_pack_start (GTK_BOX (box), data->scale, TRUE, TRUE, 0);
+	
+	gtk_container_add (GTK_CONTAINER (event), box);
+	gtk_container_add (GTK_CONTAINER (inner_frame), event);
+	
 	gtk_widget_show_all (inner_frame);
 	
 	/*
@@ -753,23 +842,23 @@ mixer_popup_show (MixerData *data)
 	/*
 	 * Grab focus and pointer.
 	 */
-	gtk_widget_grab_focus (data->scale);
-	gtk_grab_add (data->scale);
+	gtk_widget_grab_focus (data->popup);
+	gtk_grab_add (data->popup);
 
-	pointer = gdk_pointer_grab (data->scale->window,
+	pointer = gdk_pointer_grab (data->popup->window,
 				    TRUE,
-				    (GDK_BUTTON_PRESS_MASK
-				     | GDK_BUTTON_RELEASE_MASK
+				    (GDK_BUTTON_PRESS_MASK |
+				    GDK_BUTTON_RELEASE_MASK
 				     | GDK_POINTER_MOTION_MASK),
 				    NULL, NULL, GDK_CURRENT_TIME);
 	
-	keyboard = gdk_keyboard_grab (data->scale->window,
+	keyboard = gdk_keyboard_grab (data->popup->window,
 				      TRUE,
 				      GDK_CURRENT_TIME);
 	
 	if (pointer != GDK_GRAB_SUCCESS || keyboard != GDK_GRAB_SUCCESS) {
 		/* We could not grab. */
-		gtk_grab_remove (data->scale);
+		gtk_grab_remove (data->popup);
 		gtk_widget_destroy (data->popup);
 		data->popup = NULL;
 		data->scale = NULL;
@@ -828,7 +917,8 @@ destroy_mixer_cb (GtkWidget *widget, MixerData *data)
 		gtk_timeout_remove (data->timeout);
 		data->timeout = 0;
 	}
-	
+	if (data->error_dialog)
+		gtk_widget_destroy (data->error_dialog);
 	g_free (data);
 }
 
@@ -887,8 +977,8 @@ mixer_start_gmix_cb (BonoboUIComponent *uic,
 		dialog = gtk_message_dialog_new (NULL,
 						 GTK_DIALOG_DESTROY_WITH_PARENT,
 						 GTK_MESSAGE_ERROR,
-						 GTK_BUTTONS_CLOSE,
-						 _("There was an error executing '%s' : %s"),
+						 GTK_BUTTONS_OK,
+						 _("There was an error executing '%s': %s"),
 						 run_mixer_cmd,
 						 error->message);
 
@@ -1002,10 +1092,53 @@ cb_row_selected (GtkTreeSelection *selection, MixerData *data)
 	panel_applet_gconf_set_int (applet, "channel", data->mixerchannel, NULL);
 }
 
+static void
+show_help_cb (GtkWindow *dialog)
+{
+	GError *error = NULL;
+	static GnomeProgram *applet_program = NULL;
+	
+	if (!applet_program) {
+		int argc = 1;
+		char *argv[2] = { "mixer_applet2" };
+		applet_program = gnome_program_init ("mixer_applet2", VERSION,
+						      LIBGNOME_MODULE, argc, argv,
+     						      GNOME_PROGRAM_STANDARD_PROPERTIES, NULL);
+	}
+
+	egg_help_display_desktop_on_screen (
+			applet_program, "mixer_applet2", "mixer_applet2", NULL,
+			gtk_widget_get_screen (GTK_WIDGET (dialog)),
+			&error);
+
+	if (error) {
+		GtkWidget *error_dialog;
+
+		error_dialog = gtk_message_dialog_new (
+				NULL,
+				GTK_DIALOG_DESTROY_WITH_PARENT,
+				GTK_MESSAGE_ERROR,
+				GTK_BUTTONS_OK,
+				_("There was an error displaying help: %s"),
+				error->message);
+
+		g_signal_connect (error_dialog, "response",
+				  G_CALLBACK (gtk_widget_destroy),
+				  NULL);
+
+		gtk_window_set_resizable (GTK_WINDOW (error_dialog), FALSE);
+		gtk_window_set_screen (GTK_WINDOW (error_dialog),
+				       gtk_widget_get_screen (GTK_WIDGET (dialog)));
+		gtk_widget_show (error_dialog);
+		g_error_free (error);
+	}
+}
+
 static void
 dialog_response (GtkDialog *dialog, gint id, MixerData *data)
 {
 	if (id == GTK_RESPONSE_HELP) {
+		show_help_cb (GTK_WINDOW (dialog));
 		return;
 	}
 	
@@ -1041,22 +1174,25 @@ mixer_pref_cb (BonoboUIComponent *uic,
                                                    GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
                                                    GTK_STOCK_HELP, GTK_RESPONSE_HELP,
                                                    NULL);
+	gnome_window_icon_set_from_file (GTK_WINDOW (dialog), GNOME_ICONDIR"/mixer/gnome-mixer-applet.png");	
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_CLOSE);
+	gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
 	gtk_window_set_screen (GTK_WINDOW (dialog),
                            gtk_widget_get_screen (GTK_WIDGET (data->applet)));
+        gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
         gtk_window_set_default_size (GTK_WINDOW (dialog), 300, 300);
         data->prefdialog = dialog;
                            
 	vbox = GTK_DIALOG (dialog)->vbox;
 	
 	vbox1 = gtk_vbox_new (FALSE, 18);
-	gtk_container_set_border_width (GTK_CONTAINER (vbox1), 12);
+	gtk_container_set_border_width (GTK_CONTAINER (vbox1), 5);
 	gtk_box_pack_start (GTK_BOX (vbox), vbox1, TRUE, TRUE, 0);
 	
 	vbox2 = gtk_vbox_new (FALSE, 6);
         gtk_box_pack_start (GTK_BOX (vbox1), vbox2, TRUE, TRUE, 0);
         
-        tmp = g_strdup_printf ("<b>%s</b>", _("Channels"));
+        tmp = g_strdup_printf ("<b>%s</b>", _("Audio Channels"));
         label = gtk_label_new (NULL);
         gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
         gtk_label_set_markup (GTK_LABEL (label), tmp);
@@ -1072,6 +1208,10 @@ mixer_pref_cb (BonoboUIComponent *uic,
 	vbox3 = gtk_vbox_new (FALSE, 6);
 	gtk_box_pack_start (GTK_BOX (hbox), vbox3, TRUE, TRUE, 0);
 	
+	label = gtk_label_new_with_mnemonic (_("_Select channel to control:"));
+	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+	gtk_box_pack_start (GTK_BOX (vbox3), label, FALSE, FALSE, 0);
+	
 	scrolled = gtk_scrolled_window_new(NULL,NULL);
 	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolled),
 						GTK_POLICY_AUTOMATIC,
@@ -1080,6 +1220,7 @@ mixer_pref_cb (BonoboUIComponent *uic,
 	
 	model = gtk_list_store_new (2, G_TYPE_STRING, G_TYPE_POINTER);
 	tree = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
+	gtk_label_set_mnemonic_widget (GTK_LABEL (label), tree);
 	gtk_container_add (GTK_CONTAINER (scrolled), tree);
 	g_object_unref (G_OBJECT (model));
 	cell = gtk_cell_renderer_text_new ();
@@ -1301,15 +1442,7 @@ mixer_applet_create (PanelApplet *applet)
 #endif
 	mixer_init_stock_icons ();
 	if (!retval) {
-		GtkWidget *dialog;
-		dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_DESTROY_WITH_PARENT,
-						 GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE,
-						 ("Couldn't open mixer device %s\n"),
-						 device, NULL);
-		gtk_window_set_screen (GTK_WINDOW (dialog),
-				       gtk_widget_get_screen (GTK_WIDGET (applet)));
-		gtk_dialog_run (GTK_DIALOG (dialog));
-		gtk_widget_destroy (dialog);
+		device_present = FALSE;
 	}
 
  	if (GTK_IS_ACCESSIBLE (gtk_widget_get_accessible(GTK_WIDGET(applet)))) {
@@ -1325,6 +1458,7 @@ mixer_applet_create (PanelApplet *applet)
 	if (run_mixer_cmd == NULL) 
 		run_mixer_cmd = g_find_program_in_path ("sdtaudiocontrol");
 	
+	data->device = g_strdup (device);
 	data->frame = gtk_frame_new (NULL);
 	gtk_frame_set_shadow_type (GTK_FRAME (data->frame), GTK_SHADOW_NONE);
 	gtk_container_add (GTK_CONTAINER (applet), data->frame);
@@ -1346,7 +1480,7 @@ mixer_applet_create (PanelApplet *applet)
 	} 
 	
 	g_signal_connect (data->applet,
-			  "button-release-event",
+			  "button-press-event",
 			  (GCallback) applet_button_release_event_cb,
 			  data);
 	
